@@ -1,6 +1,7 @@
 from subprocess import call, check_output, PIPE, STDOUT
 from os import chdir, makedirs, getcwd, path
 from hitchtest import HitchPackage, utils
+from hitchtest.environment import checks
 import python_build
 import shutil
 import sys
@@ -41,6 +42,12 @@ class PythonPackage(HitchPackage):
             )
         else:
             self.directory = directory
+
+        checks.packages([
+            "libreadline6", "libreadline6-dev", "zlib1g-dev", "libxml2", "libxml2-dev",
+            "build-essential", "libssl-dev", "libbz2-dev", "libsqlite3-dev", "sqlite3",
+            "libtool",
+        ])
         self.bin_directory = bin_directory
 
 
